#!/bin/bash

function quit {
    echo "Press any key to exit"
    read -p "" -n 1
    echo ""
    exit $1
}

cd "$(dirname "$0")"

echo "This script will DISABLE debug mode for the print provider on this system."
echo "Hostname: `hostname`"
echo ""
echo "The print provider will be automatically restarted."
echo ""
read -p "Are you sure? [y/n] " -n 1
if [[ ! $REPLY =~ ^[Yy]$ ]]
then
    echo ""
    echo "Debug logging has NOT been disabled."
    quit 1 
fi

# Get root ----
use_sudo=
sudo_cmd=

# If the user is not already root
if [ 'id -u' != 0 ]
    
then
    # Check if sudo is found
    if which sudo >/dev/null 2>&1; then
            echo
            echo "Root access is required.  Use:"
            echo "  [1] su    - requires the root password (default)"
            echo "  [2] sudo  - if user ${APP_USER} has sudo access"
            echo "Enter 1 or 2: "
            read reply leftover
            case $reply in
                [2] | [sS][uU][dD][oO])
                    use_sudo=1
                    ;;
            esac
    fi

    if [ ! -z "${use_sudo}" ]; then
        # Use sudo
        sudo_cmd="sudo su -c"
        echo "Enter your sudo password if requested/required:"
    else
        # Use su
        sudo_cmd="su -c"
        echo "Enter the root password when requested:"
    fi
fi
# -------------

echo ""
${sudo_cmd} "sed -i \"s/.*debug=.*/debug=off/\" print-provider.conf"
echo ""

# Check if SystemD is installed.
hassystemd=false
if [ "`cat /proc/1/comm`" = "systemd" ]; then
    hassystemd=true
fi

echo "Restarting the print provider..."
if $hassystemd; then
    ${sudo_cmd} "systemctl restart pc-event-monitor.service"
else
    ${sudo_cmd} "/etc/init.d/papercut-event-monitor restart"
fi
echo ""

quit 0
