#!/usr/bin/env bash

# Copyright (c) 2020 PaperCut Software International Pty. Ltd.
#
# This is the main entry point for initialising the Print Deploy Client. This
# will trigger a call to the initialise.sh script of the latest vfolder in the current directory.
# This design allows us to push an updated initiliase.sh script via Silver.
#
# The initialise.sh script is meant to be called for the following scenarios:
#   1. To open the PaperCut Print Deploy Client window
#   2. To start usercontextservice
#
# This script is meant to be run as a non-root user. It is ideally called during startup
# or as executable script of a desktop entry file.

# Allow each line to be logged in out log file and ensure that uninitialised vars cause
# this script to fail early
set -xu

# the directory where this script is in
CURRENT_DIR=$(cd "$(dirname "${0}")" && pwd)

# This finds the name of the latest vfolder
LATEST_VFOLDER=$(cd /opt/PaperCutPrintDeployClient && ls -d -t v* | head -1)

# log file will be stored in the user's application directory
LOGDIR=~/.local/share/PaperCutPrintDeployClient/data/logs
LOGFILE=$LOGDIR/initialise.sh.log

# the name of the script in the latest vfolder to execute
INITIALISE_SCRIPT="initialise.sh"

initLogFile() {
    # always create an empty one. we don't need to keep track of old logs
    if [ ! -d $LOGDIR ]; then
        echo "Logdir not yet created. Creating"
        mkdir --parents $LOGDIR
    fi
    : > $LOGFILE
    exec &> >(
        while read -r line; do
            echo "$(date '+%Y-%m-%d %H:%M:%S'): $line" >> $LOGFILE
        done
    )
}

main() {
    initLogFile
    /bin/bash "${CURRENT_DIR}/${LATEST_VFOLDER}/${INITIALISE_SCRIPT}" "$@"
}

main "$@"
